@@ -11,9 +11,10 @@ org.gnome.ScreenSaver object.
 # of the license.
 
 __author__ = 'Bastien Nocera'
-__email__ = 'hadess@hadess.net'
-__copyright__ = '(c) 2013 Red Hat Inc.'
-__license__ = 'LGPL 3+'
+__copyright__ = '''
+(c) 2013 Red Hat Inc.
+(c) 2017 - 2022 Martin Pitt <martin@piware.de>
+'''
 
 BUS_NAME = 'org.gnome.ScreenSaver'
 MAIN_OBJ = '/org/gnome/ScreenSaver'
@@ -21,7 +22,7 @@ MAIN_IFACE = 'org.gnome.ScreenSaver'
 SYSTEM_BUS = False
 
 
-def load(mock, parameters):
+def load(mock, _parameters):
     mock.AddMethods(MAIN_IFACE, [
         ('GetActive', '', 'b', 'ret = self.is_active'),
         ('GetActiveTime', '', 'u', 'ret = 1'),
